import { formatTypeBoxErrors, validateWithTypeBox, } from '@hello.nrfcloud.com/proto';
import { ValidationFailedError } from './validateInput.js';
export class ResponseValidationFailedError extends ValidationFailedError {
    constructor(errors) {
        super(errors, 'Response validation failed');
        this.name = 'ResponseValidationFailedError';
    }
}
export const validateResponse = (schema) => {
    const validator = validateWithTypeBox(schema);
    return {
        after: async (req) => {
            const maybeValid = validator(req.response);
            if ('errors' in maybeValid) {
                console.error(`[validateResponse]`, `Response validation failed`, JSON.stringify({
                    response: req.response,
                    errors: formatTypeBoxErrors(maybeValid.errors),
                }));
                throw new ResponseValidationFailedError(maybeValid.errors);
            }
            console.debug(`[validateResponse]`, `Response is`, schema.title);
            return undefined;
        },
    };
};
